# Experiment Notebook
Python library to design, run and plot experiments.

`pip install enb`

Ideal for cases where:

	- multiple inputs need to be processed by one or more customizable tasks, producing a table of data
	- one wants to apply custom code to existing data to produce new columns
	- analysis tables and plots are needed for one or more data columns

Also take a look at the `templates` and the `plugins` folder for some examples.

You can read the documentation and browse the code at https://miguelinux314.github.io/experiment-notebook.

You are welcome to submit your extensions via a pull request to the `dev` branch.

Main developer:

	- Miguel Hernández-Cabronero <miguel.hernandez@uab.cat>

Contributors:

	- Ester Jara <ester.jara@uab.cat>
	- Natàlia Blasco <natalia.blasco@uab.cat>
	- Artur Llabrés <artur.llabres@uab.cat>
	- Ashwin Kumar Gururajan <ashwin.gururajan@uab.cat>

See CHANGELOG.md for a list of recent changes
